summaryrefslogtreecommitdiffstats
path: root/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp')
-rw-r--r--kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp b/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp
index a898d4dd..9da00dfe 100644
--- a/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp
+++ b/kviewshell/plugins/djvu/libdjvu/GIFFManager.cpp
@@ -325,24 +325,24 @@ GIFFChunk::get_chunks_number(const GUTF8String &name)
//************************************************************************
void
-GIFFManager::add_chunk(GUTF8String tqparent_name, const GP<GIFFChunk> & chunk,
+GIFFManager::add_chunk(GUTF8String parent_name, const GP<GIFFChunk> & chunk,
int pos)
// tqparent_name is the fully qualified name of the PARENT
// IT MAY BE EMPTY
// All the required chunks will be created
// pos=-1 means to append the chunk
{
- DEBUG_MSG("GIFFManager::add_chunk(): Adding chunk to name='" << tqparent_name << "'\n");
+ DEBUG_MSG("GIFFManager::add_chunk(): Adding chunk to name='" << parent_name << "'\n");
DEBUG_MAKE_INDENT(3);
if (!top_level->get_name().length())
{
- if ((!tqparent_name.length())||(tqparent_name[0]!='.'))
+ if ((!parent_name.length())||(parent_name[0]!='.'))
G_THROW( ERR_MSG("GIFFManager.no_top_name") );
- if (tqparent_name.length() < 2)
+ if (parent_name.length() < 2)
{
// 'chunk' is actually the new top-level chunk
- DEBUG_MSG("since tqparent_name=='.', making the chunk top-level\n");
+ DEBUG_MSG("since parent_name=='.', making the chunk top-level\n");
if (!chunk->is_container())
G_THROW( ERR_MSG("GIFFManager.no_top_cont") );
top_level=chunk;
@@ -350,33 +350,33 @@ GIFFManager::add_chunk(GUTF8String tqparent_name, const GP<GIFFChunk> & chunk,
}
DEBUG_MSG("Setting the name of the top-level chunk\n");
- const int next_dot=tqparent_name.search('.',1);
+ const int next_dot=parent_name.search('.',1);
if(next_dot>=0)
{
- top_level->set_name(tqparent_name.substr(1,next_dot-1));
+ top_level->set_name(parent_name.substr(1,next_dot-1));
}else
{
- top_level->set_name(tqparent_name.substr(1,(unsigned int)-1));
+ top_level->set_name(parent_name.substr(1,(unsigned int)-1));
}
}
DEBUG_MSG("top level chunk name='" << top_level->get_name() << "'\n");
- if (tqparent_name.length() && tqparent_name[0] == '.')
+ if (parent_name.length() && parent_name[0] == '.')
{
- int next_dot=tqparent_name.search('.',1);
+ int next_dot=parent_name.search('.',1);
if(next_dot<0)
{
- next_dot=tqparent_name.length();
+ next_dot=parent_name.length();
}
- GUTF8String top_name=tqparent_name.substr(1,next_dot-1);
+ GUTF8String top_name=parent_name.substr(1,next_dot-1);
if (!top_level->check_name(top_name))
G_THROW( ERR_MSG("GIFFManager.wrong_name") "\t"+top_name);
- tqparent_name=tqparent_name.substr(next_dot,(unsigned int)-1);
+ parent_name=parent_name.substr(next_dot,(unsigned int)-1);
}
GP<GIFFChunk> cur_sec=top_level;
- const char * start, * end=(const char *)tqparent_name-1;
+ const char * start, * end=(const char *)parent_name-1;
do
{
for(start=++end;*end&&(*end!='.');end++)
@@ -325,24 +325,24 @@ GIFFChunk::get_chunks_number(const GUTF8String &name)
int pos)
- // tqparent_name is the fully qualified name of the PARENT
+ // parent_name is the fully qualified name of the PARENT
// IT MAY BE EMPTY
// All the required chunks will be created